import React from 'react';
import { View, TouchableOpacity, StyleSheet } from 'react-native';
import Icon from 'react-native-vector-icons/MaterialIcons';

const DynamicLineWithIcons = ({ 
  lineColor, 
  lineThickness, 
  startIcon, 
  endIcon, 
  centerIcon,
  startIconColor,
  endIconColor,
  centerIconColor,
  onStartIconPress, 
  onEndIconPress, 
  onCenterIconPress 
}) => {
  
  // Manejadores para los eventos onPress
  const handleIconPress = (action) => {
    if (action && typeof action === 'function') {
      action();
    }
  };

  const styles = StyleSheet.create({
    line: {
      backgroundColor: lineColor, 
      height: lineThickness, 
      flex: 1,
      alignSelf: 'center',
    },
    icon: {
      padding: 10, // Ajuste para dar espacio alrededor del icono y que sea más fácil de tocar
    }
  });

  return (
    <View style={{ flexDirection: 'row', alignItems: 'center', justifyContent: 'center' }}>
      {startIcon && (
        <TouchableOpacity style={styles.icon} onPress={() => handleIconPress(onStartIconPress)}>
          <Icon name={startIcon} size={lineThickness * 2} color={startIconColor} />
        </TouchableOpacity>
      )}

      <View style={styles.line} />

      {centerIcon && (
        <TouchableOpacity style={styles.icon} onPress={() => handleIconPress(onCenterIconPress)}>
          <Icon name={centerIcon} size={lineThickness * 2} color={centerIconColor} />
        </TouchableOpacity>
      )}

      <View style={styles.line} />

      {endIcon && (
        <TouchableOpacity style={styles.icon} onPress={() => handleIconPress(onEndIconPress)}>
          <Icon name={endIcon} size={lineThickness * 2} color={endIconColor} />
        </TouchableOpacity>
      )}
    </View>
  );
};

export default DynamicLineWithIcons;
